@@ -1,7 +1,8 @@
-package Search::Elasticsearch::Client::0_90::Async::Bulk;
-$Search::Elasticsearch::Client::0_90::Async::Bulk::VERSION = '5.00';
-use Moo;
-with 'Search::Elasticsearch::Client::0_90::Role::Bulk',
+package Search::Elasticsearch::Client::1_0::Async::Bulk;
+$Search::Elasticsearch::Client::1_0::Async::Bulk::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Client::1_0::Async::Bulk::VERSION = '6.8001';use Moo;
+with 'Search::Elasticsearch::Client::1_0::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Async';
 
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -124,9 +125,7 @@ sub reindex {
     if ( ref $src eq 'HASH' ) {
         $src = $self->_hash_to_scroll( {%$src}, $transform );
     }
-    elsif ( blessed($src)
-        && $src->isa('Search::Elasticsearch::Client::0_90::Scroll') )
-    {
+    elsif ( blessed($src) && $src->isa('Search::Elasticsearch::Client::1_0::Scroll') ) {
         my $scroll = $src;
         $src = sub {
             $scroll->refill_buffer;
@@ -137,9 +136,7 @@ sub reindex {
     my $promise;
 
     # async scroll
-    if ( blessed($src)
-        && $src->isa('Search::Elasticsearch::Client::0_90::Async::Scroll') )
-    {
+    if ( blessed($src) && $src->isa('Search::Elasticsearch::Client::1_0::Async::Scroll') ) {
         $promise = $src->start;
     }
     else {
@@ -209,11 +206,11 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::0_90::Async::Bulk - A helper module for the Bulk API and for reindexing
+Search::Elasticsearch::Client::1_0::Async::Bulk - A helper module for the Bulk API and for reindexing
 
 =head1 VERSION
 
-version 5.00
+version 6.80_01
 
 =head1 SYNOPSIS
 
@@ -256,19 +253,19 @@ version 5.00
 
 =head1 DESCRIPTION
 
-This module provides an async wrapper for the L<Search::Elasticsearch::Client::0_90::Direct/bulk()>
+This module provides an async wrapper for the L<Search::Elasticsearch::Client::1_0::Direct/bulk()>
 method which makes it easier to run multiple create, index, update or delete
 actions in a single request. It also provides a simple interface
 for L<reindexing documents|/REINDEXING DOCUMENTS>.
 
-The L<Search::Elasticsearch::Client::0_90::Async::Bulk> module acts as a queue, buffering up actions
+The L<Search::Elasticsearch::Client::1_0::Async::Bulk> module acts as a queue, buffering up actions
 until it reaches a maximum count of actions, or a maximum size of JSON request
 body, at which point it issues a C<bulk()> request.
 
 Once you have finished adding actions, call L</flush()> to force the final
 C<bulk()> request on the items left in the queue.
 
-This class does L<Search::Elasticsearch::Client::0_90::Role::Bulk> and
+This class does L<Search::Elasticsearch::Client::1_0::Role::Bulk> and
 L<Search::Elasticsearch::Role::Is_Async>.
 
 =head1 CREATING A NEW INSTANCE
@@ -294,13 +291,13 @@ L<Search::Elasticsearch::Role::Is_Async>.
 
     );
 
-The C<bulk_helper> method loads L<Search::Elasticsearch::Client::0_90::Async::Bulk>,
+The C<bulk_helper> method loads L<Search::Elasticsearch::Client::1_0::Async::Bulk>,
 calls L</new()> with the specified parameters and returns a new C<$bulk> object.
 
 The C<index> and C<type> parameters provide default values for
 C<index> and C<type>, which can be overridden in each action.
 You can also pass any other values which are accepted
-by the L<bulk()|Search::Elasticsearch::Client::0_90::Direct/bulk()> method.
+by the L<bulk()|Search::Elasticsearch::Client::1_0::Direct/bulk()> method.
 
 See L</flush()> for more information about the other parameters.
 
@@ -311,7 +308,7 @@ See L</flush()> for more information about the other parameters.
     $promise = $bulk->flush;
 
 The C<flush()> method sends all buffered actions to Elasticsearch using
-a L<bulk()|Search::Elasticsearch::Client::0_90::Direct/bulk()> request and returns
+a L<bulk()|Search::Elasticsearch::Client::1_0::Direct/bulk()> request and returns
 a L<Promise>, which is rejected if the bulk request fails or if any of
 the C<on_success>, C<on_error> or C<on_conflict> callbacks throws an
 exception, otherwise it is resolved with the items that have been flushed.
@@ -517,7 +514,7 @@ they must be specified either in L</new()> or in every action.
     );
 
 The C<create()> helper method allows you to add multiple C<create> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::0_90::Direct/create()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/create()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -543,7 +540,7 @@ you can just pass the individual document bodies.
     );
 
 The C<index()> helper method allows you to add multiple C<index> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::0_90::Direct/index()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/index()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -556,7 +553,7 @@ parameter, instead of as C<body>.
     );
 
 The C<delete()> helper method allows you to add multiple C<delete> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::0_90::Direct/delete()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/delete()>.
 
 =head2 C<delete_ids()>
 
@@ -581,17 +578,17 @@ In this case, all you have to do is to pass in a list of IDs.
     );
 
 The C<update()> helper method allows you to add multiple C<update> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::0_90::Direct/update()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/update()>.
 An update can either use a I<partial doc> which gets merged with an existing
 doc (example 1 above), or can use a C<script> to update an existing doc
 (example 2 above). More information on C<script> can be found here:
-L<Search::Elasticsearch::Client::0_90::Direct/update()>.
+L<Search::Elasticsearch::Client::1_0::Direct/update()>.
 
 =head1 REINDEXING DOCUMENTS
 
 A common use case for bulk indexing is to reindex a whole index when
 changing the type mappings or analysis chain. This typically
-combines bulk indexing with L<scrolled searches|Search::Elasticsearch::Client::0_90::Scroll>:
+combines bulk indexing with L<scrolled searches|Search::Elasticsearch::Client::1_0::Scroll>:
 the scrolled search pulls all of the data from the source index, and
 the bulk indexer indexes the data into the new index.
 
@@ -609,7 +606,7 @@ the source for the documents which are to be reindexed.
 =head2 Reindexing from another index
 
 If the C<source> argument is a HASH ref, then the hash is passed to
-L<Search::Elasticsearch::Client::0_90::Async::Scroll/new()> to create a new scrolled search.
+L<Search::Elasticsearch::Client::1_0::Async::Scroll/new()> to create a new scrolled search.
 
     $bulk = $es->bulk_helper->new(
         index   => 'new_index',
@@ -742,11 +739,11 @@ the C<version> numbers from the original index, then you need the following:
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
